/**********************************************************
** (C) Keisuke Kondo
** Upload Date: March 31, 2018
** 
** Replication Code and Data 
** 
** [Required Stata Modules]
** - getisord
** - moransi
** - spgen
** NOTE: Install moransi and spgen from SSC Archive
** 
** [Reference]
** Kondo, K (2015) "Spatial persistence of Japanese unemployment rates,"
** Japan and the World Economy, 36, pp. 113-122, 2015.
**
**********************************************************/

**
log using "LOG/LOG_Estimation_getisord.smcl", replace smcl

/*
** ##### CONTENT #####
** 1. Getis-Ord G*i(d) Statistic
** 1.1. ALL Workers
** 1.2. Male worker, 15-29, 30-49, 50-64
** 1.3. Female worker, 15-29, 30-49, 50-64
** 2. List Unemployment Clusters
** 2.1. ALL Workers
** 2.2. Male worker, 15-29, 30-49, 50-64
** 2.3. Female worker, 15-29, 30-49, 50-64
** ###################
*/

/**************************************
** 1. Getis-Ord G*i(d) Statistic
**
**************************************/

/* 
** ====================================
** 1.1. ALL Workers
** ====================================
*/
**
use "DTA_ur_1980_2005_all.dta", clear

**
matrix mGO_ALL = J(6,5,0)
local j = 0
** 
forvalues i = 1980(5)2005 {
	** Counter
	local j = `j'+1
	** Getis-Ord G*(d)
	getisord ur`i', lat(lat) lon(lon) swm(bin) dist(30) dunit(km) approx
	** Summary Table
	qui: count if go_z_ur`i'_b <= invnormal(0.005)
	matrix mGO_ALL[`j',1] = r(N)
	qui: count if go_z_ur`i'_b >= invnormal(0.995)
	matrix mGO_ALL[`j',5] = r(N)
	qui: count if go_z_ur`i'_b <= invnormal(0.025)
	matrix mGO_ALL[`j',2] = r(N) - mGO_ALL[`j',1]
	qui: count if go_z_ur`i'_b >= invnormal(0.975)
	matrix mGO_ALL[`j',4] = r(N) - mGO_ALL[`j',5]
	qui: count 
	matrix mGO_ALL[`j',3] = r(N) - mGO_ALL[`j',1]-mGO_ALL[`j',2]-mGO_ALL[`j',4]-mGO_ALL[`j',5]
}
matrix rownames mGO_ALL = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mGO_ALL = "(-INF,-2.58]" "(-2.58,-1.96]" "(-1.96,1.96)" "[1,96,2.58)" "[2.58,+INF)"
matrix list mGO_ALL

** 
save "DTA_ur_1980_2005_all_GO.dta", replace


/* 
** ====================================
** 1.2. Male worker, 15-29, 30-49, 50-64
** ====================================
*/
**
use "DTA_ur_1980_2005_male.dta", clear

**
matrix mGO_1529M = J(6,5,0)
matrix mGO_3049M = J(6,5,0)
matrix mGO_5064M = J(6,5,0)
local j = 0
**
forvalues i = 1980(5)2005 {
	** Counter
	local j = `j'+1
	** Getis-Ord G*(d)
	getisord ur1529m`i', lat(lat) lon(lon) swm(bin) dist(30) dunit(km) approx
	** Summary Table
	qui: count if go_z_ur1529m`i'_b <= invnormal(0.005)
	matrix mGO_1529M[`j',1] = r(N)
	qui: count if go_z_ur1529m`i'_b >= invnormal(0.995)
	matrix mGO_1529M[`j',5] = r(N)
	qui: count if go_z_ur1529m`i'_b <= invnormal(0.025)
	matrix mGO_1529M[`j',2] = r(N) - mGO_1529M[`j',1]
	qui: count if go_z_ur1529m`i'_b >= invnormal(0.975)
	matrix mGO_1529M[`j',4] = r(N) - mGO_1529M[`j',5]
	qui: count 
	matrix mGO_1529M[`j',3] = r(N) - mGO_1529M[`j',1]-mGO_1529M[`j',2]-mGO_1529M[`j',4]-mGO_1529M[`j',5]

	** Getis-Ord G*(d)
	getisord ur3049m`i', lat(lat) lon(lon) swm(bin) dist(30) dunit(km) approx
	** Summary Table
	qui: count if go_z_ur3049m`i'_b <= invnormal(0.005)
	matrix mGO_3049M[`j',1] = r(N)
	qui: count if go_z_ur3049m`i'_b >= invnormal(0.995)
	matrix mGO_3049M[`j',5] = r(N)
	qui: count if go_z_ur3049m`i'_b <= invnormal(0.025)
	matrix mGO_3049M[`j',2] = r(N) - mGO_3049M[`j',1]
	qui: count if go_z_ur3049m`i'_b >= invnormal(0.975)
	matrix mGO_3049M[`j',4] = r(N) - mGO_3049M[`j',5]
	qui: count 
	matrix mGO_3049M[`j',3] = r(N) - mGO_3049M[`j',1]-mGO_3049M[`j',2]-mGO_3049M[`j',4]-mGO_3049M[`j',5]

	** Getis-Ord G*(d)
	getisord ur5064m`i', lat(lat) lon(lon) swm(bin) dist(30) dunit(km) approx
	** Summary Table
	qui: count if go_z_ur5064m`i'_b <= invnormal(0.005)
	matrix mGO_5064M[`j',1] = r(N)
	qui: count if go_z_ur5064m`i'_b >= invnormal(0.995)
	matrix mGO_5064M[`j',5] = r(N)
	qui: count if go_z_ur5064m`i'_b <= invnormal(0.025)
	matrix mGO_5064M[`j',2] = r(N) - mGO_5064M[`j',1]
	qui: count if go_z_ur5064m`i'_b >= invnormal(0.975)
	matrix mGO_5064M[`j',4] = r(N) - mGO_5064M[`j',5]
	qui: count 
	matrix mGO_5064M[`j',3] = r(N) - mGO_5064M[`j',1]-mGO_5064M[`j',2]-mGO_5064M[`j',4]-mGO_5064M[`j',5]
}
matrix rownames mGO_1529M = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mGO_1529M = "(-INF,-2.58]" "(-2.58,-1.96]" "(-1.96,1.96)" "[1,96,2.58)" "[2.58,+INF)"
matrix list mGO_1529M
matrix rownames mGO_3049M = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mGO_3049M = "(-INF,-2.58]" "(-2.58,-1.96]" "(-1.96,1.96)" "[1,96,2.58)" "[2.58,+INF)"
matrix list mGO_3049M
matrix rownames mGO_5064M = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mGO_5064M = "(-INF,-2.58]" "(-2.58,-1.96]" "(-1.96,1.96)" "[1,96,2.58)" "[2.58,+INF)"
matrix list mGO_5064M

** Save Results
save "DTA_ur_1980_2005_male_GO.dta", replace


/* 
** ====================================
** 1.3. Female worker, 15-29, 30-49, 50-64
** ====================================
*/
**
use "DTA_ur_1980_2005_female.dta", clear

**
matrix mGO_1529F = J(6,5,0)
matrix mGO_3049F = J(6,5,0)
matrix mGO_5064F = J(6,5,0)
local j = 0
**
**
forvalues i = 1980(5)2005 {
	** Counter
	local j = `j'+1
	** Getis-Ord G*(d)
	getisord ur1529f`i', lat(lat) lon(lon) swm(bin) dist(30) dunit(km) approx
	** Summary Table
	qui: count if go_z_ur1529f`i'_b <= invnormal(0.005)
	matrix mGO_1529F[`j',1] = r(N)
	qui: count if go_z_ur1529f`i'_b >= invnormal(0.995)
	matrix mGO_1529F[`j',5] = r(N)
	qui: count if go_z_ur1529f`i'_b <= invnormal(0.025)
	matrix mGO_1529F[`j',2] = r(N) - mGO_1529F[`j',1]
	qui: count if go_z_ur1529f`i'_b >= invnormal(0.975)
	matrix mGO_1529F[`j',4] = r(N) - mGO_1529F[`j',5]
	qui: count 
	matrix mGO_1529F[`j',3] = r(N) - mGO_1529F[`j',1]-mGO_1529F[`j',2]-mGO_1529F[`j',4]-mGO_1529F[`j',5]

	** Getis-Ord G*(d)
	getisord ur3049f`i', lat(lat) lon(lon) swm(bin) dist(30) dunit(km) approx
	** Summary Table
	qui: count if go_z_ur3049f`i'_b <= invnormal(0.005)
	matrix mGO_3049F[`j',1] = r(N)
	qui: count if go_z_ur3049f`i'_b >= invnormal(0.995)
	matrix mGO_3049F[`j',5] = r(N)
	qui: count if go_z_ur3049f`i'_b <= invnormal(0.025)
	matrix mGO_3049F[`j',2] = r(N) - mGO_3049F[`j',1]
	qui: count if go_z_ur3049f`i'_b >= invnormal(0.975)
	matrix mGO_3049F[`j',4] = r(N) - mGO_3049F[`j',5]
	qui: count 
	matrix mGO_3049F[`j',3] = r(N) - mGO_3049F[`j',1]-mGO_3049F[`j',2]-mGO_3049F[`j',4]-mGO_3049F[`j',5]

	** Getis-Ord G*(d)
	getisord ur5064f`i', lat(lat) lon(lon) swm(bin) dist(30) dunit(km) approx
	** Summary Table
	qui: count if go_z_ur5064f`i'_b <= invnormal(0.005)
	matrix mGO_5064F[`j',1] = r(N)
	qui: count if go_z_ur5064f`i'_b >= invnormal(0.995)
	matrix mGO_5064F[`j',5] = r(N)
	qui: count if go_z_ur5064f`i'_b <= invnormal(0.025)
	matrix mGO_5064F[`j',2] = r(N) - mGO_5064F[`j',1]
	qui: count if go_z_ur5064f`i'_b >= invnormal(0.975)
	matrix mGO_5064F[`j',4] = r(N) - mGO_5064F[`j',5]
	qui: count 
	matrix mGO_5064F[`j',3] = r(N) - mGO_5064F[`j',1]-mGO_5064F[`j',2]-mGO_5064F[`j',4]-mGO_5064F[`j',5]
}
matrix rownames mGO_1529F = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mGO_1529F = "(-INF,-2.58]" "(-2.58,-1.96]" "(-1.96,1.96)" "[1,96,2.58)" "[2.58,+INF)"
matrix list mGO_1529F
matrix rownames mGO_3049F = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mGO_3049F = "(-INF,-2.58]" "(-2.58,-1.96]" "(-1.96,1.96)" "[1,96,2.58)" "[2.58,+INF)"
matrix list mGO_3049F
matrix rownames mGO_5064F = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mGO_5064F = "(-INF,-2.58]" "(-2.58,-1.96]" "(-1.96,1.96)" "[1,96,2.58)" "[2.58,+INF)"
matrix list mGO_5064F

** Save Results
save "DTA_ur_1980_2005_female_GO.dta", replace





/**************************************
** 2. List Unemployment Clusters
**
**************************************/
**
clear
use "DTA_ur_1980_2005_all_GO.dta", clear

**
merge 1:1 id_muni_new using "DTA_ur_1980_2005_male_GO.dta", keepusing(ur* go_*)
drop _merge

**
merge 1:1 id_muni_new using "DTA_ur_1980_2005_female_GO.dta", keepusing(ur* go_*)
drop _merge



/* 
** ====================================
** 2.1. ALL Workers
** ====================================
*/
**

**
gen d_hsc_all = (go_z_ur1980_b > invnormal(0.975) & go_z_ur1985_b > invnormal(0.975) & /*
	*/ go_z_ur1990_b > invnormal(0.975) & go_z_ur1995_b > invnormal(0.975) & /*
	*/ go_z_ur2000_b > invnormal(0.975) & go_z_ur2005_b > invnormal(0.975) )

**
gen d_csc_all = (go_z_ur1980_b < invnormal(0.025) & go_z_ur1985_b < invnormal(0.025) & /*
	*/ go_z_ur1990_b < invnormal(0.025) & go_z_ur1995_b < invnormal(0.025) & /*
	*/ go_z_ur2000_b < invnormal(0.025) & go_z_ur2005_b < invnormal(0.025) )

**
gen d_cluster_all = .
replace d_cluster_all = d_hsc if d_hsc == 1 & d_cluster_all == .
replace d_cluster_all = -d_csc if d_csc == 1 & d_cluster_all == .
replace d_cluster_all = 0 if d_cluster_all == . 

** List Unemployment Clusters
list id_muni_new name_pref_en name_muni_en if d_cluster_all == 1


/* 
** ====================================
** 2.2. Male worker, 15-29, 30-49, 50-64
** ====================================
*/
**

**
local varlist `" "1529m" "3049m" "5064m" "'
disp `varlist'
**
foreach v of local varlist {
	gen d_hsc_`v' = (go_z_ur`v'1980_b > invnormal(0.975) & go_z_ur`v'1985_b > invnormal(0.975) & /*
		*/ go_z_ur`v'1990_b > invnormal(0.975) & go_z_ur`v'1995_b > invnormal(0.975) & /*
		*/ go_z_ur`v'2000_b > invnormal(0.975) & go_z_ur`v'2005_b > invnormal(0.975) )

	**
	gen d_csc_`v' = (go_z_ur`v'1980_b < invnormal(0.025) & go_z_ur`v'1985_b < invnormal(0.025) & /*
		*/ go_z_ur`v'1990_b < invnormal(0.025) & go_z_ur`v'1995_b < invnormal(0.025) & /*
		*/ go_z_ur`v'2000_b < invnormal(0.025) & go_z_ur`v'2005_b < invnormal(0.025) )

	**
	gen d_cluster_`v' = .
	replace d_cluster_`v' = d_hsc_`v' if d_hsc_`v' == 1 & d_cluster_`v' == .
	replace d_cluster_`v' = -d_csc_`v' if d_csc_`v' == 1 & d_cluster_`v' == .
	replace d_cluster_`v' = 0 if d_cluster_`v' == . 
}

** List Unemployment Clusters
list id_muni_new name_pref_en name_muni_en if d_cluster_1529m == 1
list id_muni_new name_pref_en name_muni_en if d_cluster_3049m == 1
list id_muni_new name_pref_en name_muni_en if d_cluster_5064m == 1


/* 
** ====================================
** 2.3. Female worker, 15-29, 30-49, 50-64
** ====================================
*/
**

**
local varlist `" "1529f" "3049f" "5064f" "'
disp `varlist'
**
foreach v of local varlist {
	gen d_hsc_`v' = (go_z_ur`v'1980_b > invnormal(0.975) & go_z_ur`v'1985_b > invnormal(0.975) & /*
		*/ go_z_ur`v'1990_b > invnormal(0.975) & go_z_ur`v'1995_b > invnormal(0.975) & /*
		*/ go_z_ur`v'2000_b > invnormal(0.975) & go_z_ur`v'2005_b > invnormal(0.975) )

	**
	gen d_csc_`v' = (go_z_ur`v'1980_b < invnormal(0.025) & go_z_ur`v'1985_b < invnormal(0.025) & /*
		*/ go_z_ur`v'1990_b < invnormal(0.025) & go_z_ur`v'1995_b < invnormal(0.025) & /*
		*/ go_z_ur`v'2000_b < invnormal(0.025) & go_z_ur`v'2005_b < invnormal(0.025) )

	**
	gen d_cluster_`v' = .
	replace d_cluster_`v' = d_hsc_`v' if d_hsc_`v' == 1 & d_cluster_`v' == .
	replace d_cluster_`v' = -d_csc_`v' if d_csc_`v' == 1 & d_cluster_`v' == .
	replace d_cluster_`v' = 0 if d_cluster_`v' == . 
}

** List Unemployment Clusters
list id_muni_new name_pref_en name_muni_en if d_cluster_1529f == 1
list id_muni_new name_pref_en name_muni_en if d_cluster_3049f == 1
list id_muni_new name_pref_en name_muni_en if d_cluster_5064f == 1



**
log close
