/**********************************************************
** (C) Keisuke Kondo
** Upload Date: March 31, 2018
** 
** Replication Code and Data 
** 
** [Required Stata Modules]
** - getisord
** - moransi
** - spgen
** NOTE: Install moransi and spgen from SSC Archive
** 
** [Reference]
** Kondo, K (2015) "Spatial persistence of Japanese unemployment rates,"
** Japan and the World Economy, 36, pp. 113-122, 2015.
**
**********************************************************/

**
log using "LOG/LOG_Estimation_moransi.smcl", replace smcl

/*
** ##### CONTENT #####
** 1. Moran Scatter Plot
** 1.1. ALL Workers
** 1.2. Male worker, 15-29, 30-49, 50-64
** 1.3. Female worker, 15-29, 30-49, 50-64
** 2. Moran's I
** 2.1. ALL Workers
** 2.2. Male worker, 15-29, 30-49, 50-64
** 2.3. Female worker, 15-29, 30-49, 50-64
** ###################
*/

/**************************************
** 1. Moran Scatter Plot
**
**************************************/

/* 
** ====================================
** 1.1. All Workers
** ====================================
*/
**
use "DTA_ur_1980_2005_all.dta", clear

** 
forvalues i = 1980(5)2005 {
	** Standardize
	qui: egen std_ur`i' = std(ur`i')
	qui: spgen std_ur`i', lat(lat) lon(lon) swm(pow 2) dist(.) dunit(km) approx
	qui: rename splag1_std_ur`i'_p w_std_ur`i'
}

save "DTA_ur_1980_2005_all_moran.dta", replace

** 
use "DTA_ur_1980_2005_all_moran.dta", clear
forvalues i = 1980(5)2005 {
	twoway (scatter w_std_ur`i' std_ur`i', ms(oh) yaxis(1 2) xaxis(1 2)) /*
		*/ (lfit w_std_ur`i' std_ur`i', lw(medthick) estopts(nocons)), /*
		*/ ytitle("W.Standardized Unemployment Rates", tstyle(size(large)) axis(1)) /*
		*/ xtitle("Standardized Unemployment Rates", tstyle(size(large)) height(6) axis(1)) /*
		*/ ytitle("", axis(2)) /*
		*/ xtitle("", axis(2)) /*
		*/ ylabel(-2(2)6, ang(h) labsize(large) format(%2.0f) nogrid axis(1)) /*
		*/ xlabel(-4(2)12, labsize(large) format(%2.0f) nogrid axis(1)) /*
		*/ ylabel(-2(2)6, ang(h) labsize(large) format(%2.0f) nogrid axis(2)) /*
		*/ xlabel(-4(2)12, labsize(large) format(%2.0f) nogrid axis(2)) /*
		*/ ysize(3) xsize(4) /*
		*/ yline(0, lwidth(thin) lcolor(gray) lpattern(dash)) /*
		*/ xline(0, lwidth(thin) lcolor(gray) lpattern(dash)) /*
		*/ legend(off) /*
		*/ graphregion(color(white) fcolor(white))
	graph export "FIG/FIG_moran_ur`i'.eps", as(eps) fontface("Palatino") replace
}


/* 
** ====================================
** 1.2. Male worker, 15-29, 30-49, 50-64
** ====================================
*/
**
use "DTA_ur_1980_2005_male.dta", clear

**
local varlist `" "1529m" "3049m" "5064m" "'
**
foreach v of local varlist {
	forvalues i = 1980(5)2005 {
		** Standardize
		qui: egen std_ur`v'`i' = std(ur`v'`i')
		qui: spgen std_ur`v'`i', lat(lat) lon(lon) swm(pow 2) dist(.) dunit(km) approx
		qui: rename splag1_std_ur`v'`i'_p w_std_ur`v'`i'
	}
}

save "DTA_ur_1980_2005_male_moran.dta", replace


**
use "DTA_ur_1980_2005_male_moran.dta", clear
local varlist `" "1529m" "3049m" "5064m" "'
**
foreach v of local varlist {
	forvalues i = 1980(5)2005 {
		twoway (scatter w_std_ur`v'`i' std_ur`v'`i', ms(oh) yaxis(1 2) xaxis(1 2)) /*
			*/ (lfit w_std_ur`v'`i' std_ur`v'`i', lw(medthick) estopts(nocons)), /*
			*/ ytitle("W.Standardized Unemployment Rates", tstyle(size(large)) axis(1)) /*
			*/ xtitle("Standardized Unemployment Rates", tstyle(size(large)) height(6) axis(1)) /*
			*/ ytitle("", axis(2)) /*
			*/ xtitle("", axis(2)) /*
			*/ ylabel(-2(2)6, ang(h) labsize(large) format(%2.0f) nogrid axis(1)) /*
			*/ xlabel(-4(2)12, labsize(large) format(%2.0f) nogrid axis(1)) /*
			*/ ylabel(-2(2)6, ang(h) labsize(large) format(%2.0f) nogrid axis(2)) /*
			*/ xlabel(-4(2)12, labsize(large) format(%2.0f) nogrid axis(2)) /*
			*/ ysize(3) xsize(4) /*
			*/ yline(0, lwidth(thin) lcolor(gray) lpattern(dash)) /*
			*/ xline(0, lwidth(thin) lcolor(gray) lpattern(dash)) /*
			*/ legend(off) /*
			*/ graphregion(color(white) fcolor(white))
		graph export "FIG/FIG_moran_ur`v'`i'.eps", as(eps) fontface("Palatino") replace
	}
}




/* 
** ====================================
** 1.3. Female worker, 15-29, 30-49, 50-64
** ====================================
*/
**
use "DTA_ur_1980_2005_female.dta", clear

**
local varlist `" "1529f" "3049f" "5064f" "'
**
foreach v of local varlist {
	forvalues i = 1980(5)2005 {
		** Standardize
		qui: egen std_ur`v'`i' = std(ur`v'`i')
		qui: spgen std_ur`v'`i', lat(lat) lon(lon) swm(pow 2) dist(.) dunit(km) approx
		qui: rename splag1_std_ur`v'`i'_p w_std_ur`v'`i'
	}
}

save "DTA_ur_1980_2005_female_moran.dta", replace




**
use "DTA_ur_1980_2005_female_moran.dta", clear
local varlist `" "1529f" "3049f" "5064f" "'
**
foreach v of local varlist {
	forvalues i = 1980(5)2005 {
		twoway (scatter w_std_ur`v'`i' std_ur`v'`i', ms(oh) yaxis(1 2) xaxis(1 2)) /*
			*/ (lfit w_std_ur`v'`i' std_ur`v'`i', lw(medthick) estopts(nocons)), /*
			*/ ytitle("W.Standardized Unemployment Rates", tstyle(size(large))) /*
			*/ xtitle("Standardized Unemployment Rates", tstyle(size(large)) height(6)) /*
			*/ ytitle("", axis(2)) /*
			*/ xtitle("", axis(2)) /*
			*/ ylabel(-2(2)6, ang(h) labsize(large) format(%2.0f) nogrid axis(1)) /*
			*/ xlabel(-4(2)12, labsize(large) format(%2.0f) nogrid axis(1)) /*
			*/ ylabel(-2(2)6, ang(h) labsize(large) format(%2.0f) nogrid axis(2)) /*
			*/ xlabel(-4(2)12, labsize(large) format(%2.0f) nogrid axis(2)) /*
			*/ ysize(3) xsize(4) /*
			*/ yline(0, lwidth(thin) lcolor(gray) lpattern(dash)) /*
			*/ xline(0, lwidth(thin) lcolor(gray) lpattern(dash)) /*
			*/ legend(off) /*
			*/ graphregion(color(white) fcolor(white))
		graph export "FIG/FIG_moran_ur`v'`i'.eps", as(eps) fontface("Palatino") replace
	}
}





/**************************************
** 2. Moran's I
** 
**************************************/


/* 
** ====================================
** 1.1. All Workers
** ====================================
*/
**
use "DTA_ur_1980_2005_all.dta", clear

**
matrix mI_ALL = J(6,5,0)
local j = 0
** 
forvalues i = 1980(5)2005 {
	** Counter
	local j = `j'+1
	** Moran's I
	moransi ur`i', lat(lat) lon(lon) swm(pow 2) dist(.) dunit(km) approx
	** Summary Table
	matrix mI_ALL[`j',1] = r(I)
	matrix mI_ALL[`j',2] = r(EI)
	matrix mI_ALL[`j',3] = r(seI)
	matrix mI_ALL[`j',4] = r(zI)
	matrix mI_ALL[`j',5] = r(pI)
}
**
disp "##### Summary Table for All Workers #####"
matrix rownames mI_ALL = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mI_ALL = "I" "E(I)" "se(I)" "z(I)" "p(I)"
matrix list mI_ALL


/* 
** ====================================
** 2.2. Male worker, 15-29, 30-49, 50-64
** ====================================
*/
**
use "DTA_ur_1980_2005_male.dta", clear

**
matrix mI_1529M = J(6,5,0)
matrix mI_3049M = J(6,5,0)
matrix mI_5064M = J(6,5,0)
local j = 0
**
forvalues i = 1980(5)2005 {
	** Counter
	local j = `j'+1
	** Moran's I
	moransi ur1529m`i', lat(lat) lon(lon) swm(pow 2) dist(.) dunit(km) approx
	** Summary Table
	matrix mI_1529M[`j',1] = r(I)
	matrix mI_1529M[`j',2] = r(EI)
	matrix mI_1529M[`j',3] = r(seI)
	matrix mI_1529M[`j',4] = r(zI)
	matrix mI_1529M[`j',5] = r(pI)

	** Moran's I
	moransi ur3049m`i', lat(lat) lon(lon) swm(pow 2) dist(.) dunit(km) approx
	** Summary Table
	matrix mI_3049M[`j',1] = r(I)
	matrix mI_3049M[`j',2] = r(EI)
	matrix mI_3049M[`j',3] = r(seI)
	matrix mI_3049M[`j',4] = r(zI)
	matrix mI_3049M[`j',5] = r(pI)

	** Moran's I
	moransi ur5064m`i', lat(lat) lon(lon) swm(pow 2) dist(.) dunit(km) approx
	** Summary Table
	matrix mI_5064M[`j',1] = r(I)
	matrix mI_5064M[`j',2] = r(EI)
	matrix mI_5064M[`j',3] = r(seI)
	matrix mI_5064M[`j',4] = r(zI)
	matrix mI_5064M[`j',5] = r(pI)
}
**
disp "##### Summary Table for Male Workers Aged 15-29 #####"
matrix rownames mI_1529M = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mI_1529M = "I" "E(I)" "se(I)" "z(I)" "p(I)"
matrix list mI_1529M
**
disp "##### Summary Table for Male Workers Aged 30-49 #####"
matrix rownames mI_3049M = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mI_3049M = "I" "E(I)" "se(I)" "z(I)" "p(I)"
matrix list mI_3049M
**
disp "##### Summary Table for Male Workers Aged 50-64 #####"
matrix rownames mI_5064M = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mI_5064M = "I" "E(I)" "se(I)" "z(I)" "p(I)"
matrix list mI_5064M


/* 
** ====================================
** 2.3. Female worker, 15-29, 30-49, 50-64
** ====================================
*/
**
use "DTA_ur_1980_2005_female.dta", clear

**
matrix mI_1529F = J(6,5,0)
matrix mI_3049F = J(6,5,0)
matrix mI_5064F = J(6,5,0)
local j = 0
**
forvalues i = 1980(5)2005 {
	** Counter
	local j = `j'+1
	** Moran's I
	moransi ur1529f`i', lat(lat) lon(lon) swm(pow 2) dist(.) dunit(km) approx
	** Summary Table
	matrix mI_1529F[`j',1] = r(I)
	matrix mI_1529F[`j',2] = r(EI)
	matrix mI_1529F[`j',3] = r(seI)
	matrix mI_1529F[`j',4] = r(zI)
	matrix mI_1529F[`j',5] = r(pI)

	** Moran's I
	moransi ur3049f`i', lat(lat) lon(lon) swm(pow 2) dist(.) dunit(km) approx
	** Summary Table
	matrix mI_3049F[`j',1] = r(I)
	matrix mI_3049F[`j',2] = r(EI)
	matrix mI_3049F[`j',3] = r(seI)
	matrix mI_3049F[`j',4] = r(zI)
	matrix mI_3049F[`j',5] = r(pI)

	** Moran's I
	moransi ur5064f`i', lat(lat) lon(lon) swm(pow 2) dist(.) dunit(km) approx
	** Summary Table
	matrix mI_5064F[`j',1] = r(I)
	matrix mI_5064F[`j',2] = r(EI)
	matrix mI_5064F[`j',3] = r(seI)
	matrix mI_5064F[`j',4] = r(zI)
	matrix mI_5064F[`j',5] = r(pI)
}
**
disp "##### Summary Table for Female Workers Aged 15-29 #####"
matrix rownames mI_1529F = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mI_1529F = "I" "E(I)" "se(I)" "z(I)" "p(I)"
matrix list mI_1529F
**
disp "##### Summary Table for Female Workers Aged 30-49 #####"
matrix rownames mI_3049F = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mI_3049F = "I" "E(I)" "se(I)" "z(I)" "p(I)"
matrix list mI_3049F
**
disp "##### Summary Table for Female Workers Aged 50-64 #####"
matrix rownames mI_5064F = "1980" "1985" "1990" "1995" "2000" "2005"
matrix colnames mI_5064F = "I" "E(I)" "se(I)" "z(I)" "p(I)"
matrix list mI_5064F


**
log close
